Interpolated

Struct Interpolated 

pub struct Interpolated<T> { /* private fields */ }
A wrapper that simplifies state interpolation between fixed logic updates.

It keeps track of the ‘previous’ and ‘current’ values and automatically performs linear interpolation when requested.

Example

use spottedcat::{Context, DrawOption, Image, Pt, Spot};
use spottedcat::math::Interpolated;

struct Player {
    pos: Interpolated<[f32; 2]>,
    sprite: Image,
}

impl Spot for Player {
    fn initialize(ctx: &mut Context) -> Self {
        let sprite = Image::new(ctx, Pt::from(1.0), Pt::from(1.0), &[255, 255, 255, 255])
            .unwrap();
        Self {
            pos: Interpolated::new([0.0, 0.0]),
            sprite,
        }
    }

    fn update(&mut self, _ctx: &mut Context, _dt: std::time::Duration) {
        // Update the target value. Previous becomes current.
        let next_x = self.pos.target()[0] + 1.0;
        self.pos.update([next_x, 0.0]);
    }

    fn draw(&mut self, ctx: &mut Context, screen: Image) {
        // Read the smoothly interpolated value for the current render frame
        let pos = self.pos.value(ctx);
        screen.draw(
            ctx,
            &self.sprite,
            DrawOption::default().with_position([Pt::from(pos[0]), Pt::from(pos[1])]),
        );
    }
}

Implementations

Source

impl<T: Interpolatable + Copy> Interpolated<T>

pub fn new(val: T) -> Self

Creates a new interpolated value.

pub fn update(&mut self, next: T)

Updates the value. The current value becomes the previous value.

pub fn teleport(&mut self, val: T)

Sets both current and previous to the same value (teleport).

pub fn target(&self) -> T

Returns the raw current target value.

pub fn previous(&self) -> T

Returns the raw previous value.

pub fn value(&self, ctx: &Context) -> T

Returns the interpolated value based on the current context’s draw interpolation.