pub struct Context { /* private fields */ }Expand description
Drawing context for managing render commands.
The context accumulates drawing commands during a frame and is used by the graphics system to render the scene.
Implementations
Sourceimpl Context
impl Context
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new drawing context.
This is typically done automatically by the run function, but can be
used to create a new context manually if needed.
pub fn set_window_logical_size(&mut self, width: Pt, height: Pt)
pub fn window_logical_size(&self) -> (Pt, Pt)
pub fn vw(&self, percent: f32) -> Pt
pub fn vh(&self, percent: f32) -> Pt
pub fn insert_resource<T: Any>(&mut self, value: Rc<T>)
pub fn get_resource<T: Any>(&self) -> Option<Rc<T>>
pub fn remove_resource<T: Any>(&mut self) -> Option<Rc<T>>