pub struct DrawOption { /* private fields */ }Expand description
Unified options for drawing images and text.
Controls the position, rotation, and scale of drawn items.
Implementations
Sourceimpl DrawOption
impl DrawOption
Sourcepub fn new(position: [Pt; 2], rotation: f32, scale: [f32; 2]) -> Self
pub fn new(position: [Pt; 2], rotation: f32, scale: [f32; 2]) -> Self
Creates a new DrawOption with position, rotation, and scale.
pub fn position(&self) -> [Pt; 2]
Sourcepub fn with_position(self, position: [Pt; 2]) -> Self
pub fn with_position(self, position: [Pt; 2]) -> Self
Sets the drawing position relative to the current target’s top-left corner.
pub fn set_position(&mut self, x: Pt, y: Pt)
pub fn rotation(&self) -> f32
Sourcepub fn with_rotation(self, rotation: f32) -> Self
pub fn with_rotation(self, rotation: f32) -> Self
Sets the rotation in radians.
pub fn scale(&self) -> [f32; 2]
Sourcepub fn with_scale(self, scale: [f32; 2]) -> Self
pub fn with_scale(self, scale: [f32; 2]) -> Self
Sets the scale multiplier (e.g., [2.0, 2.0] for double size).
pub fn opacity(&self) -> f32
Sourcepub fn with_opacity(self, opacity: f32) -> Self
pub fn with_opacity(self, opacity: f32) -> Self
Sets the opacity (alpha multiplier), from 0.0 to 1.0.